""" 

Context : SRP
Module  : REM
Version : 1.1.0
Author  : Stefano Covino
Date    : 07/01/2014
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (24/08/2012) First version.
        : (22/08/2013) Funtions reordered.
        : (28/08/2013) New functions.
        : (16/09/2013) New functions.
        : (07/01/2014) Better organization of functions.
"""


__all__ = ['Classic', 'Extra', 'ExtraExt', 'FindOrigCoord', 'Full', 'minClassic', 'minExtra', 'minFull',
                'minSimple', 'Simple']


PMFlavours = ['classic', 'extra', 'full', 'simple']